@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20240329';
+our $VERSION = '0.20240430';
 
-# Table last modified: 2024-03-29
+# Table last modified: 2024-04-30
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[0-2]1|55|77|88)|612))',
     '002' => '(?:850[1-4])',
@@ -35,11 +35,11 @@ our %ZIP_TABLE = (
     '028' => '(?:(?:8(?:0(?:4[02]|3[01])|392|696)|7(?:39[2-7]|[15]92|995)|4(?:39[358]|19[35])|(?:0[135]|1[13])92|6(?:19[23568]|892)|3(?:69[2457]|392)|5495))',
     '029' => '(?:(?:4(?:19[245]|29[23]|59[23])|2(?:29[23]|396)|(?:01|56)92))',
     '030' => '(?:(?:8(?:5(?:3[03]|7[047]|8[058]|0[235]|[14][0135]|5[02-8]|2[0-4]|6[0167])|6(?:04|22|49|55|77|86|6[78]|1[01]))|01(?:9[26-8]|8[013-68])|1(?:49[26]|393|798)))',
-    '031' => '(?:8(?:5(?:20|4[3-5]|3[38]|5[0158]|7[07]|8[58]|0[1457]|1[01])|6(?:55|86|1[17]|0[18])))',
+    '031' => '(?:8(?:5(?:20|5[158]|4[3-5]|3[38]|7[07]|8[58]|0[1457]|1[01])|6(?:55|86|1[17]|0[18])))',
     '033' => '(?:86(?:04|66|88))',
     '034' => '(?:(?:8(?:6(?:05|28|1[358])|5(?:65|78))|039[238]))',
     '035' => '(?:8686)',
-    '036' => '(?:(?:8(?:5(?:11|22|45|77|0[1-3]|6[0-47]|5[0158]|8[58]|3[038])|6(?:01|42|55|66|8[689])|7(?:77|88))|1(?:59[23]|393|492)|039[26]))',
+    '036' => '(?:(?:8(?:5(?:11|22|45|77|0[1-3]|5[018]|6[0-47]|8[58]|3[038])|6(?:01|42|55|66|8[689])|7(?:77|88))|1(?:59[23]|393|492)|039[26]))',
     '037' => '(?:(?:86(?:01|55|86)|0392))',
     '038' => '(?:(?:3(?:19[2-5]|39[2-4]|[68]92|595)|85(?:[08]5|[56]0)|0(?:19[24]|292)|139[23]|279[23]))',
     '039' => '(?:(?:2(?:2(?:9[23]|8[0-35-79])|59[2-578]|49[23]|79[23]|[13]92|696)|11(?:9[237]|8[0159])|0(?:[258]92|19[58])|4(?:29[23]|495|692)|3393))',
@@ -63,7 +63,7 @@ our %ZIP_TABLE = (
     '057' => '(?:85(?:11|58))',
     '058' => '(?:(?:0292|8501))',
     '059' => '(?:(?:1(?:39[2-6]|59[2-6]|69[23]|292)|0(?:59[2568]|99[3578]|49[236])|2(?:[14]92|598)|8[67]01|3195))',
-    '060' => '(?:8(?:5(?:[38]\d|4[1-9]|[12][0-35-9]|6[0135-9]|7[02-9]|0[1-68]|5[0-46-9])|6(?:1\d|5[14-68]|8[6-8]|7[016-8]|0[1-9]|6[16-8]|2[1-57-9]|4[0-46-9]|3[0-24-9])|7(?:11|67|2[015]|9[5-7]|7[46]|0[35-7])|406))',
+    '060' => '(?:8(?:5(?:[38]\d|4[1-9]|[12][0-35-9]|6[0135-9]|7[02-9]|0[1-68]|5[0-46-9])|6(?:1\d|5[14-68]|8[6-8]|7[016-8]|0[1-9]|6[16-8]|2[1-57-9]|4[0-46-9]|3[0-24-9])|7(?:11|67|9[5-7]|7[46]|0[35-7]|2[15])|406))',
     '061' => '(?:(?:1(?:39[2-6]|49[236-8]|19[256])|0(?:29[2356]|59[25]|692)|3(?:29[2-6]|197|692)|2292|8501))',
     '062' => '(?:8(?:6(?:86|1[278]|0[1-357-9]|3[0135]|2[24]|4[12]|6[68])|5(?:01|20|7[025]|1[013467]|5[58]|3[029])))',
     '063' => '(?:8(?:5(?:22|0[17]|5[58]|[18][05])|6(?:0[1-36-8]|1[12]|4[15])))',
@@ -105,13 +105,13 @@ our %ZIP_TABLE = (
     '099' => '(?:(?:2(?:19[2-8]|49[235]|392)|1(?:49[2568]|19[78]|595)|3(?:29[23]|69[78])|4(?:19[256]|492)|(?:56|65)92|049[245]))',
     '100' => '(?:(?:8(?:9(?:4[015]|3[0-37]|6[0-2457-9]|8[0-3679]|9[46]|2[0-24679]|1[02-9]|0[1-579]|5[0-35689]|7[013-9])|1(?:7[2468]|1[0137-9]|8[124-9]|2[013-8]|0[1-57-9]|6[05689]|4[0-24]|5[0-24589]|3[0-69])|2(?:28|51|70|0[1357]|8[23578]|3[2-5]|1[4-69]|4[156]|6[0258])|3(?:70|5[015]|3[2358]|2[1245]|0[2367]|4[15]|1[01]|8[038])|5(?:11|33|4[03]|5[058]|6[07]|8[58]|7[57]|2[0-2]|0[235-7])|6(?:55|2[019]|3[19]|6[356]|7[67]|1[07]|0[126]|4[049])|4(?:5[06]|1[015]|0[25]|3[09]|2[147]|[48][48])|0(?:19|5[015]|7[07-9]|8[068]|6[56])|79[1-4])|6(?:1(?:62|7[0-57]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]))',
     '101' => '(?:8(?:4(?:1[0568]|6[0-246]|7[057]|4[13-68]|3[0379]|8[05]|0[58]|5[0169]|2[1-59])|6(?:8[28]|0[356]|5[146]|6[578]|3[01367]|7[026]|4[235-8]|2[146-9]|1[01679])|3(?:8[38]|5[013-589]|4[367]|0[17-9]|3[3568]|1[0138]|2[3-69]|7[258]|6[267])|5(?:3[0-245]|6[1258]|7[59]|4[28]|1[25]|0[249]|8[0569]|2[0-578]|5[24589])|7(?:0[137]|1[0-25-8])|9(?:41|50|7[37]|8[36])|2(?:28|0[14]|1[0359])|0(?:11|5[04]|0[128])|1(?:01|89)))',
-    '102' => '(?:8(?:1(?:2[02-58]|8[124-8]|5[0-25]|3[0-289]|0[1-39]|7[0-25-8]|9[0-5]|4[0-24]|6[016]|1[0-257-9])|5(?:0[2-468]|4[013]|5[2-9]|7[01378]|3[0-39]|2[02589]|1[0-3569]|6[013-79]|8[023568])|6(?:3[0-3579]|4[2-5]|2[0-26-8]|8[0589]|7[17-9]|1[0-47-9]|5[0156]|6[06-8]|0[1-4679])|4(?:7[047]|6[0-24-68]|5[0-259]|0[124-7]|4[0158]|2[0146]|8[489]|3[037]|1[01479])|2(?:5[015]|7[2357]|3[0-24-68]|6[045]|8[28]|2[1-68]|[01][15]|4[016])|3(?:7[0-37]|3[1-36]|2[124]|1[0134]|8[1-38]|6[24]|4[139]|5[0367]|0[1359])|0(?:30|77|8[0-358]|2[256]|5[05]|0[58]|1[125689])|7(?:30|9[58])))',
-    '103' => '(?:8(?:4(?:7[0-3]|0[1-57]|6[0-24-68]|4[38]|3[0-589]|1[0-79]|2[24-7]|8[02457-9]|5[016])|2(?:5[0-2569]|3\d|6[01356]|7[036-8]|0[1-68]|8[2457]|1[0-248]|2[124589]|4[013578])|3(?:70|0[1378]|8[0348]|4[15-7]|1[1-478]|5[0-248]|6[036]|3[01357-9]|2[13-58])|5(?:1[0-257]|5[12468]|7[17]|0[1-36]|2[0-25]|6[67]|8[4-68]|3[4-8]|4[238])|6(?:40|5[0136]|3[169]|7[67]|6[068]|8[0469])|0[01]1))',
+    '102' => '(?:8(?:1(?:1[0-357-9]|2[02-58]|8[124-8]|5[0-25]|3[0-289]|0[1-39]|7[0-25-8]|9[0-5]|4[0-24]|6[016])|5(?:0[2-468]|4[013]|5[2-9]|7[01378]|3[0-39]|2[02589]|1[0-3569]|6[013-79]|8[023568])|6(?:3[0-3579]|4[2-5]|2[0-26-8]|8[0589]|7[17-9]|1[0-47-9]|5[0156]|6[06-8]|0[1-4679])|4(?:7[047]|6[0-24-68]|5[0-259]|0[124-7]|4[0158]|2[0146]|8[489]|3[037]|1[01479])|2(?:5[015]|3[0-24-68]|6[045]|8[28]|7[2-57]|2[1-68]|[01][15]|4[016])|3(?:7[0-37]|3[1-36]|2[124]|1[0134]|8[1-38]|6[24]|4[139]|5[0367]|0[1359])|0(?:30|77|8[0-358]|2[256]|5[05]|0[58]|1[125689])|7(?:30|9[58])))',
+    '103' => '(?:8(?:4(?:7[0-3]|0[1-57]|6[0-24-68]|4[38]|3[0-589]|1[0-79]|2[24-7]|8[02457-9]|5[016])|2(?:5[0-2569]|3\d|7[036-8]|0[1-68]|8[2457]|1[0-248]|6[0156]|2[124589]|4[013578])|3(?:70|0[1378]|8[0348]|4[15-7]|1[1-478]|5[0-248]|6[036]|3[01357-9]|2[13-58])|5(?:1[0-257]|5[12468]|7[17]|0[1-36]|2[0-25]|6[67]|8[4-68]|3[4-8]|4[238])|6(?:40|5[0136]|3[169]|7[67]|6[068]|8[0469])|0[01]1))',
     '104' => '(?:(?:8(?:1(?:2[2-589]|5[018]|6[12578]|4[25]|8[389]|7[014-689]|3[0-589]|1[0-24-8]|0[124589])|3(?:1[023579]|7[07-9]|2[458]|8[013689]|6[35]|5[0167]|3[02358]|4[0-5]|0[12467])|4(?:5[06]|3[013589]|1[369]|0[24578]|8[168]|2[0-469]|6[078]|4[02-49])|5(?:3[03]|2[136-8]|4[357]|5[014-689]|6[068]|1[078]|8[1458]|0[1256])|2(?:38|40|71|6[26]|5[124578]|0[568]|8[0-59]|1[0-28])|6(?:14|78|5[06]|8[05]|6[15])|0(?:55|77|1[01]|0[1-37]))|6241))',
-    '105' => '(?:(?:8(?:4(?:7[0-257]|8[2-6]|5[1-36-8]|3[13-7]|[46][014-9]|2[0347-9]|1[0-24-9]|0[1-378])|5(?:6[03578]|1[0-2568]|0[1-357-9]|5[013-8]|8[0-57-9]|7[4-9]|2[1-57-9]|3[0457]|4[03-6])|6(?:7[026-8]|3[04]|8[01569]|6[0568]|1[013-5]|2[0135-7]|5[468]|4[0-24]|0[3468])|3(?:1\d|3[01358]|2[235]|0[1-8])|0(?:10|39|55|0[1258]|7[07]|8[58])|7(?:88|0[127]|1[267]))|7(?:0(?:[58]0|77)|36[5-7]|444)|6[09]50))',
+    '105' => '(?:(?:8(?:4(?:7[0-257]|8[2-6]|5[1-36-8]|3[13-7]|[46][014-9]|2[0347-9]|1[0-24-9]|0[1-378])|5(?:6[03578]|1[0-2568]|0[1-357-9]|5[013-8]|8[0-57-9]|7[4-9]|2[1-57-9]|3[0457]|4[03-6])|6(?:7[026-8]|3[04]|8[01569]|6[0568]|1[013-5]|2[0135-7]|5[468]|4[0-24]|0[3468])|3(?:1\d|3[01358]|0[1-9]|2[235])|0(?:10|39|55|0[1258]|7[07]|8[58])|7(?:88|0[127]|1[267]))|7(?:0(?:[58]0|77)|36[5-7]|444)|6[09]50))',
     '106' => '(?:(?:8(?:5(?:6[0-35-79]|0[78]|3[17]|1[458]|7[135-8]|2[12]|5[0-25689]|4[145]|8[0157-9])|6(?:77|4[0-2489]|5[25]|1[16]|6[58]|3[0569]|0[18]|2[0256])|0(?:11|39|0[17])|(?:10|79)7|4(?:01|87))|6(?:1(?:61|88)|06[06])))',
     '107' => '(?:8(?:4(?:20|5[06]|7[127]|0[1-4]|3[14]|1[0-26-9]|8[24]|4[08]|6[038])|5(?:[37]2|81|1[14]|0[2578]|2[0178]|6[037]|5[0268]|4[56])|6(?:01|50|66|1[5-79]|7[46]|3[0-3689]|8[068]|2[0357])|3(?:60|4[0289]|7[013]|2[0346]|8[048]|3[026]|5[125])|0(?:[16]0|77|0[16])))',
-    '108' => '(?:(?:8(?:5(?:2[0-35]|4[0358]|3[02369]|0[1-9]|6[0468]|1[0-25]|7[0135]|5[0-35-8]|8[0-3568])|3(?:2[25689]|1[0356]|7[2359]|8[013-689]|3[34]|5[058]|6[01]|4[15]|0[13578])|2(?:8[028]|2[0-245]|7[056]|4[0-38]|1[0-25-7]|0[1-36-9]|3[0-4]|5[05])|4(?:56|0[3-57]|2[013-5]|7[078]|1[014-7]|3[29]|6[68]|4[48])|6(?:50|1[0-25-7]|2[28]|3[1-3689]|0[267]|4[0-28])|0(?:[258]0|[17]1|0[15])|7(?:07|1[03])|11[78])|63(?:50|63)))',
+    '108' => '(?:(?:8(?:5(?:2[0-35]|4[0358]|3[02369]|0[1-9]|6[0468]|1[0-25]|7[0135]|5[0-35-8]|8[0-3568])|3(?:2[25689]|3[134]|1[0356]|7[2359]|8[013-689]|5[058]|6[01]|4[15]|0[13578])|2(?:8[028]|2[0-245]|7[056]|4[0-38]|1[0-25-7]|0[1-36-9]|3[0-4]|5[05])|4(?:56|0[3-57]|2[013-5]|7[078]|1[014-7]|3[29]|6[68]|4[48])|6(?:50|1[0-25-7]|2[28]|3[1-3689]|0[267]|4[0-28])|0(?:[258]0|[17]1|0[15])|7(?:07|1[03])|11[78])|63(?:50|63)))',
     '109' => '(?:8792)',
     '110' => '(?:8(?:5(?:6[0-25-7]|4[01368]|7[5-8]|3[0-4679]|0[1-3579]|1[0135-7]|5[059]|8[02-468]|2[024])|6(?:53|2[0-2568]|6[0259]|3[0158]|4[124-6]|0[259]|8[015-7]|1[04589]|7[35-8])|7(?:8[027]|1[2-6]|2[235]|3[36]|0[68])|408|807))',
     '111' => '(?:8(?:6(?:3[01379]|[12][0-258]|7[6-8]|8[1368]|0[2568]|6[16]|5[05]|4[0248])|5(?:43|1[0-258]|8[058]|5[1568]|7[57]|6[0167]|2[125]|0[125-8]|3[0-59])|7(?:[56]5|21|98|0[178]|1[01])|081))',
@@ -130,8 +130,8 @@ our %ZIP_TABLE = (
     '132' => '(?:8(?:5(?:[18]5|33|5[015]|0[137]|6[27])|6(?:01|74|[68][68])|7(?:11|3[029])))',
     '133' => '(?:8(?:5(?:[01]1|8[05]|5[238])|70[46]))',
     '134' => '(?:8(?:5(?:[15]5|20|33|7[05-7]|8[5-8]|0[237])|6(?:22|86|[14][02]|0[1-39]|3[01])|702))',
-    '135' => '(?:8(?:5(?:48|7[057-9]|5\d|3[0-358]|2[1-3578]|8[1257]|1[0-478]|0[12458]|6[035-8])|4(?:4[0358]|2[27]|0[24]|5[18]|8[0-2]|7[037]|6[014]|1[15]|3[026])|6(?:86|0[28]|2[0-25]|6[168]|3[0-29]|7[078]|1[014-9]|5[059])|3(?:[25]0|8[3-57]|0[1368]|7[05]|6[023]|3[01]|1[0-28])|1(?:[46]5|21|50|78|1[01458]|0[89]|3[0479]|8[01])|7(?:97|3[0-3]|2[0-37]|0[17]|1[0178])|2(?:10|2[24])|0(?:74|80)))',
-    '136' => '(?:8(?:5(?:3[135]|4[03]|5[056]|8[01589]|1[2357]|7[057]|6[07]|0[1257]|2[1-35])|6(?:51|8[06]|1[25]|[37][0157]|2[0267]|6[68]|4[08]|0[3578])|7(?:[23]3|11)|88[08]|405|908))',
+    '135' => '(?:8(?:5(?:48|3[0-358]|7[57-9]|2[1-3578]|8[1257]|1[0-478]|5[0-24-9]|0[12458]|6[035-8])|4(?:4[0358]|2[27]|0[24]|5[18]|8[0-2]|7[037]|6[014]|1[15]|3[026])|6(?:86|0[28]|2[0-25]|6[168]|3[0-29]|7[078]|1[014-9]|5[059])|3(?:[25]0|8[3-57]|0[1368]|7[05]|6[023]|3[01]|1[0-28])|1(?:[46]5|21|50|78|1[01458]|0[89]|3[0479]|8[01])|7(?:97|3[0-3]|2[0-37]|0[17]|1[0178])|2(?:10|2[24])|0(?:74|80)))',
+    '136' => '(?:8(?:5(?:3[135]|4[03]|5[056]|8[01589]|1[2357]|7[057]|6[07]|0[1257]|2[1-35])|6(?:51|8[06]|1[25]|[37][0157]|2[0267]|6[68]|4[08]|0[3578])|7(?:[23]3|11)|88[018]|405|908))',
     '137' => '(?:8(?:6(?:23|86)|08[18]|581))',
     '140' => '(?:8(?:5(?:90|4[0137-9]|3[0136-9]|7[1-46]|8[0346]|0[236-9]|6[0367]|2[1-3569]|5[1248]|1[1256])|6(?:4[04]|3[0147]|6[013689]|2[13568]|7[025-8]|5[03-68]|0[12]|8[0278]|1[14-79])|7(?:88|1[015-7]|2[12]|0[279])|810))',
     '141' => '(?:8(?:6(?:3[017-9]|0[2-79]|8[048]|6[03-5]|2[03679]|1[01356]|7[1-379]|4[0-46-8]|5[06-8])|5(?:34|4[04]|6[0-25-9]|5[59]|2[0-25]|0[13-57]|1[02579]|8[0-248]|7[267])|4(?:8[78]|1[1-3689]|2[0-6])|2(?:55|60|1[04]|0[1-6])|7(?:1[056]|0[17])|001|924))',
@@ -153,7 +153,7 @@ our %ZIP_TABLE = (
     '161' => '(?:8(?:5(?:08|11|75|3[19]|6[057]|5[236-8]|4[0156]|2[0-28])|710))',
     '162' => '(?:8(?:6(?:[78]0|1[24-6]|2[0468]|5[04-6]|[36][689]|4[046]|0[1248])|4(?:33|5[015]|6[04]|4[058]|7[1368]|8[048]|0[27]|2[12]|1[125])|5(?:75|[16][25]|0[235]|3[05]|8[57]|5[16-8]|4[034])|8(?:30|5[03]|0[1-8]|6[01])|0(?:55|60|2[0-2]|0[15])|7(?:0[17]|1[016-8])|953))',
     '163' => '(?:(?:0(?:5(?:5[378]|7[056]|6[0269])|6(?:7[5-7]|5[59]|6[359])|8(?:50|67|3[136])|2(?:78|6[18])|4(?:56|7[18])|9(?:43|3[68])|7[27]7)|1(?:3(?:50|63|71|4[59]|8[28])|0(?:7[13]|6[156]|5[35])|4(?:55|70|88)|5(?:88|3[37]))|8(?:6(?:02|80|2[06]|3[89]|7[17]|6[016])|0(?:0[13]|8[0-2]|1[29])|5(?:35|48))))',
-    '164' => '(?:8(?:5(?:[37]0|12|55|67|4[015]|2[25]|8[58]|0[1-5])|6(?:[25]0|[68]6|7[78]|1[167]|4[24]|[03][18])|7(?:25|0[15])))',
+    '164' => '(?:8(?:6(?:[25]0|[68]6|7[78]|1[167]|4[24]|[03][18])|5(?:[37]0|55|67|4[015]|2[25]|8[58]|0[1-5])|7(?:25|0[15])))',
     '165' => '(?:8(?:(?:63|78)0|555))',
     '166' => '(?:85(?:20|88|0[1-3]|6[5-7]|4[025]|3[1-357-9]|7[078]))',
     '167' => '(?:8(?:5(?:[26]0|34|85|0[15-7]|1[05]|5[15])|6(?:10|28|0[12])|001))',
@@ -170,7 +170,7 @@ our %ZIP_TABLE = (
     '179' => '(?:8(?:9(?:0[134679]|1[14])|501))',
     '180' => '(?:8(?:5(?:66|80|1[79]|2[027]|7[17]|3[138]|0[58])|6(?:29|33|1[018]|0[28])|7(?:50|77)))',
     '181' => '(?:8(?:5(?:41|67|3[135]|7[17]|8[568]|2[128]|1[178]|0[35]|5[15])|6(?:22|33|48|1[124]|0[18])|001))',
-    '182' => '(?:8(?:5(?:08|67|70|85|2[025]|5[58]|1[0-2])|6(?:21|86|0[12])|00[16]))',
+    '182' => '(?:8(?:5(?:08|67|70|85|2[025]|5[58]|1[0-2])|6(?:21|0[12])|00[16]))',
     '183' => '(?:8(?:5(?:61|70|85|1[1-469]|2[124-689]|5[013]|3[02469]|4[0189]|0[1256])|70[1-35-7]))',
     '184' => '(?:8(?:5(?:[34]3|22|95|1[015]|5[58]|7[57]|0[1-58]|8[1458])|795))',
     '185' => '(?:8(?:5(?:[24]0|33|6[27]|0[126]|1[01])|601|795))',
@@ -202,7 +202,7 @@ our %ZIP_TABLE = (
     '214' => '(?:85(?:[26]5|8[058]|7[01]))',
     '215' => '(?:85(?:09|30|42|66|7[06]|1[015]|8[58]|5[08]|2[017]))',
     '216' => '(?:8(?:5(?:[56]6|01|22|70|1[0-249])|631))',
-    '220' => '(?:8(?:5(?:77|1[015]|6[05-7]|3[0689]|2[0-3]|5[89]|8[0568]|4[0-2]|0[127-9])|6(?:53|60|0[149]|1[1-6]|8[046]|2[035])|7(?:11|39|65|2[02]|5[05])|080|173|401))',
+    '220' => '(?:8(?:5(?:77|1[015]|3[0689]|2[0-3]|6[0-7]|5[89]|8[0568]|4[0-2]|0[127-9])|6(?:53|60|0[149]|1[1-6]|8[046]|2[035])|7(?:11|39|65|2[02]|5[05])|080|173|401))',
     '221' => '(?:8(?:5(?:[46]0|37|88|2[0239]|5[08]|1[017])|7(?:41|65|1[28]|0[1-35])|6(?:[68]6|11|23)))',
     '222' => '(?:8(?:5(?:3[03]|8[056]|6[1-6]|7[57]|0[157-9]|1[15]|5[0268]|2[035])|6[25]2))',
     '223' => '(?:85(?:7[027]|[58][058]|1[0-25]|2[0-35-7]|6[067]|4[0-2]|0[125-8]|3[039]))',
@@ -215,7 +215,7 @@ our %ZIP_TABLE = (
     '232' => '(?:8(?:5(?:31|8[057]|5[58]|1[05])|6(?:02|88)))',
     '233' => '(?:85(?:0[1-3]|5[056]))',
     '235' => '(?:85(?:58|2[23]|0[15]))',
-    '236' => '(?:8(?:5(?:15|40|0[1-4]|5[05])|6(?:5[13]|4[158])))',
+    '236' => '(?:8(?:5(?:15|40|0[1-4]|5[05])|6(?:09|5[13]|4[158])))',
     '237' => '(?:85(?:23|55|1[05]))',
     '238' => '(?:(?:8(?:5(?:70|8[058]|3[356]|1[013]|2[02]|6[57]|5[08]|4[01])|6[18]6)|029[28]))',
     '239' => '(?:8(?:5(?:01|28|60|8[58]|5[08])|68[68]))',
@@ -299,7 +299,7 @@ our %ZIP_TABLE = (
     '323' => '(?:(?:8(?:5(?:11|58|67|8[56])|6(?:[01]1|78|86)|75[56])|019[24]|1192))',
     '324' => '(?:(?:8(?:5(?:[24]0|01|85|1[06]|5[015])|6(?:25|86|4[12])|765)|0(?:59[2-6]|29[23]|69[23]|492)))',
     '325' => '(?:039[23578])',
-    '326' => '(?:(?:8(?:5(?:11|72|85|5[08]|2[01]|0[125])|6(?:[01]1|30|86))|039[25]))',
+    '326' => '(?:(?:8(?:5(?:11|72|85|5[058]|2[01]|0[125])|6(?:[01]1|30|86))|039[25]))',
     '327' => '(?:(?:8(?:5(?:11|33|55|0[13])|6(?:78|0[13]))|0(?:59[25]|192|398)))',
     '328' => '(?:(?:8(?:5(?:33|0[1-4]|5[0568]|8[5-8])|6(?:86|6[68]))|0192))',
     '329' => '(?:(?:0(?:49[238]|59[568]|69[26]|195)|1(?:19[3468]|39[235]|292|493)|2(?:79[23]|99[23]|[12]92)|4(?:49[238]|392)|3292))',
@@ -350,20 +350,20 @@ our %ZIP_TABLE = (
     '374' => '(?:(?:8(?:5(?:01|20|33|55|77|88|1[0-28])|6(?:11|22|40|86|0[18]))|019[23]))',
     '375' => '(?:8(?:50[1-7]|60[1-4]))',
     '376' => '(?:(?:8(?:5(?:31|85|1[056]|2[38]|5[58]|0[12])|6(?:86|6[68]))|0(?:19[2-4]|39[27])))',
-    '377' => '(?:(?:0(?:8(?:8[23]|9[2-46-8])|2(?:80|9[2-4])|19[235]|39[25]|49[24]|792)|8(?:5(?:[67]7|20|33|55|1[013]|0[1-38]|8[58])|616)|1(?:79[2-7]|39[235]|59[3-5]|69[235])))',
+    '377' => '(?:(?:0(?:8(?:8[23]|9[2-46-8])|2(?:80|9[2-4])|19[235]|39[25]|49[24]|792)|8(?:5(?:20|33|55|77|1[013]|6[67]|0[1-38]|8[58])|616)|1(?:79[2-7]|39[235]|59[3-5]|69[235])))',
     '378' => '(?:(?:0498|8501))',
     '379' => '(?:(?:2(?:1(?:8[014-7]|9[2-578])|39[258]|29[28])|1(?:29[78]|[16]92|393|498)|0(?:19[235-7]|292)))',
     '380' => '(?:8(?:5(?:0[1-35-8]|8[0-689]|2[014-6]|7[0235-7]|6[015-8]|5[0-3578]|4[03-6]|1[0-25689]|3[013-9])|6(?:55|77|0[158]|2[25]|8[268]|6[068]|4[08]|1[0-24]|3[039])|7(?:10|9[4-8])))',
     '381' => '(?:(?:8(?:5(?:1[015]|5[0168]|[67][07]|3[09]|0[138]|4[58]|2[05]|8[08])|6(?:02|86)|793)|0(?:2(?:88|9[235-8])|19[23]|49[78])|22(?:8[0-35-9]|9[258])|4(?:19[23]|393)))',
-    '382' => '(?:8(?:5(?:33|55|77|0[1258]|8[578]|1[0-2])|633))',
+    '382' => '(?:8(?:5(?:33|55|77|8[578]|1[0-2]|0[258])|633))',
     '383' => '(?:8(?:5(?:55|67|8[158]|[01][15])|6(?:14|86)))',
     '384' => '(?:(?:8(?:5(?:[01]1|58|8[58])|605)|0(?:69[2578]|393|798)|(?:11|22)92))',
     '385' => '(?:8(?:5(?:[01]1|22|33|8[568]|5[58])|6(?:[01]1|86)))',
     '386' => '(?:(?:8(?:5(?:[67]7|22|43|5[135]|8[458]|1[01]|0[15])|6(?:24|0[189]|8[3568]|6[68]|3[48]|1[01])|7(?:05|20|1[05]))|0(?:49[23578]|39[36]|[15]92)|1(?:19[23]|298)|2292))',
     '387' => '(?:8(?:5(?:[26]1|[58]5|0[1-3]|1[12])|60[13]))',
     '388' => '(?:85(?:11|22|55))',
-    '389' => '(?:(?:0(?:6(?:8[128]|9[235-8])|19[2-8]|29[23568]|89[2378]|59[238])|1(?:19[256]|293|392)|2(?:[1357]92|29[28])))',
-    '390' => '(?:(?:8(?:5(?:85|0[1-35-8]|2[0358]|4[013]|1[0158]|3[01359]|[56][05])|6(?:48|86|2[013]|3[09]|1[01]|0[1-35])|7(?:65|0[237]|1[0-24]))|1(?:1(?:9[378]|8[1-35-9])|29[358]|39[2-4]|[457]92)))',
+    '389' => '(?:(?:0(?:6(?:8[128]|9[235-8])|19[2-8]|29[23568]|89[2378]|59[238])|1(?:19[256]|293|392)|2[1257]92))',
+    '390' => '(?:(?:8(?:5(?:85|0[1-35-8]|2[0358]|4[013]|1[0158]|3[01359]|[56][05])|6(?:48|86|2[013]|3[09]|1[01]|0[1-35])|7(?:65|0[2-47]|1[0-24]))|1(?:1(?:9[378]|8[1-35-9])|29[358]|39[2-4]|[457]92)))',
     '391' => '(?:(?:85(?:31|40|0[13]|5[058]|6[0167]|1[0-2]|8[08]|2[125])|0(?:29[2-7]|39[2-6]|192)))',
     '392' => '(?:8(?:5(?:[58]5|20|7[78]|0[25]|4[089]|1[01])|6(?:86|2[78]|0[19]|1[01])))',
     '393' => '(?:8(?:5(?:[58]5|11|0[1-3])|601))',
@@ -424,7 +424,7 @@ our %ZIP_TABLE = (
     '450' => '(?:(?:8(?:5(?:40|85|0[135]|[23][03]|6[17]|7[57]|1[15])|6(?:[248]0|[05]1|1[1458])|7(?:11|65)|99[35-7])|6(?:(?:13|36)3|660)))',
     '451' => '(?:8(?:5(?:[14]1|2[02]|[56][0158]|0[1-38]|7[0157])|6(?:[15]0|66|88)|701))',
     '452' => '(?:8(?:5(?:70|0[1-3]|6[1-79])|60[12]))',
-    '453' => '(?:8(?:5(?:40|8[015]|3[39]|7[07]|5[58]|6[57]|2[12]|0[15]|1[0-28])|6(?:[28]6|11|62|0[18])|7(?:58|65|77|0[124])))',
+    '453' => '(?:8(?:5(?:40|8[015]|3[39]|7[07]|5[58]|6[57]|2[12]|0[15]|1[0-28])|6(?:[28]6|11|62|0[18])|7(?:58|65|77|0[14])))',
     '454' => '(?:8(?:5(?:3[03]|2[0-24-79]|5[058]|1[124-9]|6[05]|0[1-689])|651))',
     '455' => '(?:8(?:5(?:[458]5|60|1[25]|[02][15]|3[035])|6(?:[46]8|10|2[06]|3[09]|0[156]|7[01])|777))',
     '456' => '(?:8(?:5(?:23|30|44|0[1-3]|6[07]|1[16]|8[0578]|5[56])|6(?:20|91|0[12]|1[0-2]|[68][68])|7(?:11|39|63)))',
@@ -456,7 +456,7 @@ our %ZIP_TABLE = (
     '482' => '(?:8(?:5(?:01|55|1[01])|6(?:60|86|5[12])))',
     '483' => '(?:8(?:5(?:55|0[257])|7(?:14|0[14])))',
     '484' => '(?:8(?:5(?:0[1-8]|1[0-2])|609))',
-    '485' => '(?:8(?:5(?:05|40|1[0-26]|5[0-257]|2[0-3]|3[013]|6[1-35])|65[0-5]|750))',
+    '485' => '(?:8(?:5(?:05|40|1[0-26]|5[0-257]|2[0-3]|3[013]|6[1-356])|65[0-5]|750))',
     '486' => '(?:8(?:5(?:01|40|67|75|2[23]|1[015]|8[58]|5[05])|6[68]6))',
     '487' => '(?:8(?:6(?:22|50)|501))',
     '488' => '(?:8(?:5(?:[58]5|01|20|78)|6(?:55|66|8[68])))',
@@ -493,7 +493,7 @@ our %ZIP_TABLE = (
     '521' => '(?:(?:1(?:29[25]|39[28]|192)|8(?:60|5[01])1|0[23]92))',
     '522' => '(?:(?:8(?:5(?:11|0[135]|4[03]|3[39]|8[58]|2[023])|6(?:55|66))|029[27]))',
     '523' => '(?:8(?:5(?:[23]3|5[58]|1[05]|0[1-37])|651))',
-    '524' => '(?:(?:85(?:01|24|77|85)|0292))',
+    '524' => '(?:85(?:01|24|77|85))',
     '525' => '(?:85(?:77|6[67]|2[0-256]|[58][58]|1[15]|0[125]))',
     '526' => '(?:(?:8(?:5(?:01|45|58|8[05])|6(?:60|86))|029[23]))',
     '527' => '(?:(?:8(?:5(?:[27]7|42|0[158]|8[058]|6[67]|1[12]|5[0458])|687)|0195))',
@@ -750,7 +750,7 @@ our %ZIP_TABLE = (
     '789' => '(?:(?:1(?:[29]92|795)|0392))',
     '790' => '(?:8(?:5(?:0[12589]|4[0-356]|7[013-578]|5[13-7]|9[05]|6[015-7]|2[04589]|1[0-469]|3[0-579]|8[013-9])|6(?:01|32|7[78]|6[015-7]|8[68]|5[0-35689])|7(?:87|9[135-7])))',
     '791' => '(?:(?:8(?:5(?:5[015]|2[3-578]|1[0-36-8]|3[01568]|0[125-8])|6(?:0[34]|7[1257]))|0(?:2(?:8[018]|9[257])|3(?:85|9[2-578])|59[34])|3(?:19[2-8]|29[235]|[35]92)|(?:45|1[17])92|219[135]))',
-    '792' => '(?:8(?:5(?:43|67|1[018]|8[0568]|5[05]|2[01]|0[15])|6(?:14|70|86)))',
+    '792' => '(?:8(?:5(?:05|43|67|1[018]|8[0568]|5[05]|2[01])|6(?:14|70|86)))',
     '793' => '(?:8(?:5(?:[58]5|1[056]|0[19])|601))',
     '794' => '(?:(?:8(?:5(?:[56]5|82|1[018]|0[28])|6(?:1[14]|0[12]))|2(?:[124]92|39[25]|59[23])|1(?:39[23]|[14]92)|019[23]))',
     '795' => '(?:(?:8(?:5(?:10|0[124-8])|60[13])|0392))',
@@ -838,7 +838,7 @@ our %ZIP_TABLE = (
     '877' => '(?:(?:8(?:5(?:01|55)|6(?:01|86))|0(?:39[23]|296)|1292))',
     '878' => '(?:8555)',
     '879' => '(?:(?:5(?:19[235-8]|59[235]|498)|4(?:49[28]|[26]92|194)|0(?:49[2358]|692)|(?:26|6[16])92|159[2358]|719[28]))',
-    '880' => '(?:(?:8(?:5(?:7[05-7]|4[3-6]|2[02357]|1[0-357-9]|8[01368]|3[02359]|0[1-357-9]|6[167]|5[015-9])|6(?:10|25|49|3[39]|0[124-6]|6[68])|725)|1(?:19[2356]|39[28])|029[3-578]|229[23]))',
+    '880' => '(?:(?:8(?:5(?:7[05-7]|4[3-6]|2[02357]|1[0-357-9]|3[02359]|8[0168]|0[1-357-9]|6[167]|5[015-9])|6(?:10|25|49|3[39]|0[124-6]|6[68])|725)|1(?:19[2356]|39[28])|029[3-578]|229[23]))',
     '881' => '(?:85(?:01|67))',
     '882' => '(?:(?:8(?:6(?:11|66|78|8[68])|5(?:85|0[38]))|1(?:29[3-5]|192)|0192))',
     '883' => '(?:(?:85(?:01|10|33|55|8[58])|(?:01|13)92))',
@@ -876,7 +876,7 @@ our %ZIP_TABLE = (
     '917' => '(?:(?:8(?:5(?:[24]4|33|77|6[17]|5[058]|1[12]|0[57]|8[0458])|6(?:01|86))|0(?:29[378]|[13]98)))',
     '918' => '(?:8(?:5(?:4[03]|6[05-8]|1[0158]|7[0578]|2[0235]|3[037]|5[02568]|8[03568]|0[1-3589])|6(?:68|8[168])))',
     '919' => '(?:(?:0(?:59[2578]|69[2578]|[124]92|898)|1(?:39[235-7]|[15]92)|2(?:29[2-4]|392)))',
-    '920' => '(?:(?:8(?:5(?:4[0134]|2[0-25]|3[0135-9]|1[0-35-8]|7[0357]|0[1-57-9]|5[0-8]|[68][035-8])|6(?:2[0-358]|8[1568]|5[04-8]|0[125-79]|3[0-37-9]|7[0146-8]|4[0-248]|6[0156]|1[0-69])|7(?:[67]7|30|9[3-7]|0[17]|2[189]|1[0189]))|0(?:3(?:8[135-8]|9[23568])|29[235]|192)|1(?:1(?:92|8[0-245])|39[2367])|2(?:39[2-5]|19[256])|3198))',
+    '920' => '(?:(?:8(?:5(?:2[0-25]|4[013-5]|3[0135-9]|1[0-35-8]|7[0357]|0[1-57-9]|5[0-8]|[68][035-8])|6(?:2[0-358]|8[1568]|5[04-8]|0[125-79]|3[0-37-9]|7[0146-8]|4[0-248]|6[0156]|1[0-69])|7(?:[67]7|30|9[3-7]|0[17]|2[189]|1[0189]))|0(?:3(?:8[135-8]|9[23568])|29[235]|192)|1(?:1(?:92|8[0-245])|39[2367])|2(?:39[2-5]|19[256])|3198))',
     '921' => '(?:8(?:5(?:6[0-245]|5[025]|1[0-2578]|3[0-269]|0[15-8]|2[035-79]|8[0-589]|4[1468]|7[1-79])|6(?:01|16|50|3[079]|2[01])|798))',
     '922' => '(?:(?:8(?:5(?:[37]0|01|66|2[25]|8[58]|5[05]|1[01])|6(?:09|11|22|50|78|86))|0(?:29[3-578]|19[23]|49[57]|595)))',
     '923' => '(?:(?:8(?:5(?:6[05-7]|5[0-257]|8[0168]|7[058]|3[013]|2[0158]|0[1-357]|4[14-6]|1[01])|6(?:50|66|2[06]|4[02-46]|0[13569]|1[0156]|8[68]|3[039]))|1(?:29[2-7]|198)|039[238]))',
@@ -919,7 +919,7 @@ our %ZIP_TABLE = (
     '960' => '(?:(?:8(?:5(?:75|4[06]|8[014589]|5[058]|6[067]|3[0146]|2[0-4]|0[1-35-9]|1[1-3568])|6(?:48|3[39]|2[056]|7[07]|0[1-357]|6[068]|1[014]|8[68]|5[15]))|0(?:2(?:8[0239]|9[46-8])|1(?:9[245]|8[0145])|69[25]|596|893|992)|1(?:19[235-8]|29[235-7]|39[23]|[48]92)|2(?:19[3-6]|292)))',
     '961' => '(?:(?:8(?:5(?:22|1[16]|8[58]|0[18])|6(?:11|86|0[12]))|0[134]92))',
     '962' => '(?:(?:8(?:50[1-37-9]|601)|0[2356]92))',
-    '963' => '(?:(?:8(?:5(?:20|4[03]|0[1-36-8]|[13][01359]|6[0346-8]|7[0578]|5[01568]|8[03568])|6(?:[24]2|55|7[05-7]|6[014-68]|3[07]|0[129]|1[01]|8[56])|292|794)|0(?:19[25-8]|29[67])|4(?:39[368]|[16]92)|(?:6[1-3]|3[46])92|5(?:49[23]|[16]92)|7(?:796|893)|138[036-8]))',
+    '963' => '(?:(?:8(?:5(?:20|4[03]|0[1-36-8]|[13][01359]|6[0346-8]|7[078]|5[01568]|8[03568])|6(?:[24]2|55|7[05-7]|6[014-68]|3[07]|0[129]|1[01]|8[56])|292|794)|0(?:19[25-8]|29[67])|4(?:39[368]|[16]92)|(?:6[1-3]|3[46])92|5(?:49[23]|[16]92)|7(?:796|893)|138[036-8]))',
     '964' => '(?:(?:8(?:5(?:[67]7|01|58)|601)|0[23]92))',
     '965' => '(?:8(?:5(?:[347]0|67|0[1-6]|8[058]|2[02]|5[08]|1[016])|6(?:[01]1|78)))',
     '966' => '(?:(?:0(?:19[2-4]|485)|8601))',
